@@ -248,12 +248,12 @@ void carla_fill<float>(float data[], const float& value, const std::size_t count
 static inline
 float carla_findMaxNormalizedFloat(const float floats[], const std::size_t count)
 {
-    CARLA_SAFE_ASSERT_RETURN(floats != nullptr, 0.0f);
-    CARLA_SAFE_ASSERT_RETURN(count > 0, 0.0f);
+    CARLA_SAFE_ASSERT_RETURN(floats != nullptr, 0.f);
+    CARLA_SAFE_ASSERT_RETURN(count > 0, 0.f);
 
     static constexpr const float kEmptyFloats[8192] = {};
 
-    if (count <= 8192 && std::memcmp(floats, kEmptyFloats, count) == 0)
+    if (count <= 8192 && std::memcmp(floats, kEmptyFloats, sizeof(float)*count) == 0)
         return 0.0f;
 
     float tmp, maxf2 = std::abs(floats[0]);
@@ -263,14 +263,14 @@ float carla_findMaxNormalizedFloat(const float floats[], const std::size_t count
         if (!std::isfinite(floats[i]))
             __builtin_unreachable();
 
-        tmp = std::abs(*floats++);
+        tmp = std::abs(floats[i]);
 
         if (tmp > maxf2)
             maxf2 = tmp;
     }
 
-    if (maxf2 > 1.0f)
-        maxf2 = 1.0f;
+    if (maxf2 > 1.f)
+        maxf2 = 1.f;
 
     return maxf2;
 }
